# GPT4ALL Tone Analyzer

`gpt4all-tone` is a comprehensive tool for sentiment analysis and tone review, empowered by GPT4ALL. It reads a text input and evaluates the sentiment, returning a numerical value indicating the sentiment of the text.

## Installation

1. Clone this repository to your local machine or install via pip:

```bash
pip install gpt4all-tone
```

or

```bash
pip3 install gpt4all-tone
```

2. Ensure you have the `gpt4all` library installed. It will be installed automatically if you install `gpt4all-tone` via pip.

## Usage

You can use this tool via the command line or import it into your Python project.

### Command Line Usage:

```bash
gpt4all_tone --model "orca-mini-3b.ggmlv3.q4_0.bin" --char-limit 2000 "Your text here"
```

### Parameters:

- `--model`: Specifies the model name. Default is `orca-mini-3b.ggmlv3.q4_0.bin`.
- `--char-limit`: Specifies the character limit for the prompt. Default is `2000`.
- `input`: Specifies the input text to analyze.

### Python Usage:

```python
from gpt4all_tone import ToneAnalyzer

analyzer = ToneAnalyzer("orca-mini-3b.ggmlv3.q4_0.bin", "Your text here")
result = analyzer.run()
print(result)
```

## Output

The script will return a numerical value indicating the sentiment of the text based on the following scale:

- `1`: Positive tone
- `0.75`: More Positive tone
- `0.5`: Neutral tone
- `0.25`: More Negative tone
- `0`: Negative tone

In case the sentiment analysis encounters an issue or can't determine the sentiment, it will return `-1`.

## Contributing

Feel free to fork this repository, create a feature branch, and send us a pull request.

## Contact

- Author: Evgenii Evstafev
- Email: chigwel@gmail.com
- [GitHub Repository](https://github.com/chigwell/gpt4all-tone)
